function graph_Mdos(handle)
%
%GRAPH_MDOS
%
%       Graph the data in the Density of States mode.
%

global ParsecData PguiData pvoxMdos;

axes(handle);

gmin = min(min( ParsecData.EigenvalueEV ));
gmin = min( [ gmin 0 ] ) - 3*pvoxMdos.width;
gmax = max(max( ParsecData.EigenvalueEV ));
gmax = max( [ gmax 0 ] ) + 3*pvoxMdos.width;

X = (gmin: (gmax-gmin)/10000 :gmax);

if ( PguiData.draw_mode == 1 )
    set(handle, 'DrawMode', 'normal');
else
    set(handle, 'DrawMode', 'fast');
end


%tic;

if pvoxMdos.cumulative
    
    width = (0:(gmax-gmin)/(20000*pvoxMdos.width):1);
    width_r = size(width);
    width_r = width_r(2);
    width_l = ceil(width_r/2);
    width_r = floor(width_r/2);

    if pvoxMdos.occupied
        %graph occupied and cumulative
        
        Y2 = zeros(1,10001);
        Y1 = zeros(1,10001);
        Y = zeros(1,10001);

        for m=(1:ParsecData.num_states)
            val = round( (ParsecData.EigenvalueEV(m,pvoxMdos.iteration)-gmin)*((10000)/(gmax-gmin)) + 1 );
            
            %Y = Y + [ zeros(1,val-1) ones(1,10002-val) ];
            Y = Y + [ zeros(1,val-1-width_l) width ones(1,10002-val-width_r) ];
            
            val = X(val);
            Y2=Y2+ParsecData.Occup(m,pvoxMdos.iteration).*pdf('Normal', X, val, pvoxMdos.width);
            Y1=Y1+pdf('Normal', X, val, pvoxMdos.width);
        end
                
        Y = Y*(max(Y1)/ParsecData.num_states);

        % plot the graph
        plot(X,Y,'g','LineWidth',1);
        hold on
        plot(X,Y1,'LineWidth',2);
        plot(X,Y2,'r','LineWidth',2);
        hold off

    else
        %graph cumulative, but not occupied
        
        Y1 = zeros(1,10001);
        Y = zeros(1,10001);

        for m=(1:ParsecData.num_states)
            val = round( (ParsecData.EigenvalueEV(m,pvoxMdos.iteration)-gmin)*((10000)/(gmax-gmin)) + 1 );
            
            %Y = Y + [ zeros(1,val-1) ones(1,10002-val) ];
            Y = Y + [ zeros(1,val-1-width_l) width ones(1,10002-val-width_r) ];
            
            val = X(val);
            Y1=Y1+pdf('Normal', X, val, pvoxMdos.width);
        end
        Y = Y*(max(Y1)/ParsecData.num_states);

        % plot the graph
        plot(X,Y,'g','LineWidth',1);
        hold on
        plot(X,Y1,'LineWidth',2);
        hold off

    end

else

    if pvoxMdos.occupied
        %graph occupied but not cumulative

        Y2 = zeros(1,10001);
        Y1 = zeros(1,10001);

        for m=(1:ParsecData.num_states)
            val = round( (ParsecData.EigenvalueEV(m,pvoxMdos.iteration)-gmin)*((10000)/(gmax-gmin)) + 1 );
            val = X(val);
            Y2=Y2+ParsecData.Occup(m,pvoxMdos.iteration).*pdf('Normal', X, val, pvoxMdos.width);
            Y1=Y1+pdf('Normal', X, val, pvoxMdos.width);
        end

        % plot the graph
        plot(X,Y1,'LineWidth',2);
        hold on
        plot(X,Y2,'r','LineWidth',2);
        hold off

    else
        %graph neither occupied nor cumulative
                    
        Y1 = zeros(1,10001);

        for m=(1:ParsecData.num_states)
            val = round( (ParsecData.EigenvalueEV(m,pvoxMdos.iteration)-gmin)*((10000)/(gmax-gmin)) + 1 );
            val = X(val);
            Y1=Y1+pdf('Normal', X, val, pvoxMdos.width);
        end
        
        % plot the graph
        plot(X,Y1,'LineWidth',2);

    end

end


%out = toc

title('Density of States vs. Energy (eV)');

a = axis;
pvoxMdos.scale = [gmin gmax min(Y1) max(Y1)*1.2];
axis(pvoxMdos.scale);
colormap(PguiData.colormap);

if ( PguiData.draw_mode == 1 )
    set(handle, 'DrawMode', 'normal');
else
    set(handle, 'DrawMode', 'fast');
end
