## RSDFT_PARSER.py - Parses parsec.out from PARSEC ##
import re, sys

## OPEN parsec.out file ##
fname = file('./pTemp/fname.dat', 'r')
fileName = fname.readline()
fname.close()
fileName = fileName.rstrip('\n')
parsec = file(fileName, 'r')

## CREATE regular expressions ##
reNumStates= re.compile("^ Number of states")
reAtomData = re.compile("^Atom data:")
reNumAtoms = re.compile("^ Total number of atoms")
reDiagTime = re.compile("^ Diag")
reNewState = re.compile("^   State")
reFinished = re.compile("^ Finished")
reHartTime = re.compile("^Hart")
reChargeD  = re.compile("^ max and min")
reNum      = re.compile("-?[\d\.]+")
reExpNum   = re.compile("\.\d+E[\-|+][\d]+")

## FUNCTIONS ##
# NumParse - Find a number in a given string and return as a float
def NumParse(inString):
    try:
        temp = reNum.search(inString)
        temp = temp.group()
        return float(temp)
    except:
        print "NumParse: Error at pos("+str(parsec.tell())+"):"
        print inString
        parsec.close()
        sys.exit()
# NumsParse - Find a list of numbers in a given string and return as a list of floats
def NumsParse(inString):
    try:
        temp = re.findall("[^a-zA-z]-?[\d\.]+",inString) 
        for n in range(0, len(temp)): # Convert to floats
            temp[n] = float(temp[n])
        return temp
    except:
        print "NumsParse: Error at pos("+str(parsec.tell())+"):"
        print inString
        parsec.close()
        sys.exit()

## CREATE data structures ##
numStates = 0  # Stores the number of states computed
numAtoms  = 0  # Stores the number of atoms computed
timeDiag  = [] # Stores Diagonalization times [sec]
timeHart  = [] # Stores containing Hartree times [sec]
Eigenvalues = [] # Stores Eigenvalues
ChargeD     = [] # Stores max/min charge densities [e/bohr^3]

## BEGIN Parsing ##
input = parsec.readline()

## SEARCH for 'Number of states' ##
while (reNumStates.match(input) < 0):
    input = parsec.readline()
numStates = int(NumParse(input))

## SEARCH for Atom data ##
while (reAtomData.match(input) < 0):
    input = parsec.readline()

## PARSE Atom data ##
input = parsec.readline()
input = parsec.readline()

totalTypes = NumParse(input)
fAtom = file('./pTemp/atom.dat', 'w')
for n in range(1,int(totalTypes)+1):
    input = parsec.readline()
    num = NumParse(input)
    input = input.lstrip(" There are")
    input = input.rstrip("atoms\n")
    fAtom.write(input)
    fAtom.write("\n")
    input = parsec.readline()
    input = parsec.readline()
    input = parsec.readline()
    for i in range(1, int(num)+1):
        input = parsec.readline()
        locs  = NumsParse(input)
        fAtom.write("%f %f %f\n" % (locs[0], locs[1], locs[2]))
    input = parsec.readline()
fAtom.close()

## SEARCH for number of atoms ##
while (reNumAtoms.match(input) < 0):
    input = parsec.readline()
numAtoms = int(NumParse(input))

## PARSE Iteration Data ##
while (reFinished.match(input)<0): # Continue until self-consitency
    input = parsec.readline()

    ## SEARCH for Diagonalization Time ##
    if (reDiagTime.match(input)):
        timeDiag.append(NumParse(input))

    ## SEARCH for Eigenvalue Table ##
    elif (reNewState.match(input)):
        input = parsec.readline()
        input = parsec.readline()
        while (input != '\n'):

            ## READ values into 'Eigenvalues' ##
            Floats = NumsParse(input)                    
            Eigenvalues.append({'State':Floats[0], 'Eigenvalue[Ry]':Floats[1], 'Eigenvalue[eV]':Floats[2]})
            input = parsec.readline()

    ## SEARCH for Hartree Time ##
    elif (reHartTime.match(input)):
        timeHart.append(NumParse(input))

    ## SEARCH for Charge Density ##
    elif (reChargeD.match(input)):
        Floats = re.findall("\.\d+e[\-|+][\d]+", input)
        ChargeD.append({'max':float(Floats[0]), 
'min':float(Floats[1])})

    ## CHECK for EOF ##
    elif (input == ''):
        print "EOF reached unexpectedly"
        sys.exit()
## END of Iteration Data ##
    
## CLOSE parsec.out ##
parsec.close()

## Write Main Loop info to file ##
fMain = file('./pTemp/main.dat', 'w')
for n in range(0, len(timeDiag)):
    fMain.write("%E NaN %E %E %E NaN NaN NaN NaN NaN NaN NaN NaN NaN NaN NaN\n" % (timeDiag[n], timeHart[n], ChargeD[n]['min'], ChargeD[n]['max']))
fMain.close()

## Write Eigenvalues to file ##
fEig = file('./pTemp/eigenvalues.dat', 'w')
for n in range(0, len(Eigenvalues)):
    fEig.write("%f %f %f NaN NaN\n" % (Eigenvalues[n]['State'],Eigenvalues[n]['Eigenvalue[Ry]'],Eigenvalues[n]['Eigenvalue[eV]']))
fEig.close()

## Write misc to file ##
fOpts = file('./pTemp/misc.dat', 'w')
fOpts.write("%i states computed\n" % numStates)
fOpts.write("%i atoms simulated\n" % numAtoms)
fOpts.close()

## Write Forces to file ##
fForces = file('./pTemp/forces.dat', 'w')
for n in range(0, numAtoms):
    fForces.write("NaN NaN NaN ")
fForces.write("\n")
for n in range(0, numAtoms):
    fForces.write("NaN NaN NaN ")
fForces.write("\n")
for n in range(0, numAtoms):
    fForces.write("NaN NaN NaN ")
fForces.close()               

fForces2 = file('./pTemp/forces2.dat', 'w')
for n in range(0, numAtoms):
    fForces2.write("NaN NaN NaN NaN NaN NaN ")
fForces2.write("\n")
for n in range(0, numAtoms):
    fForces2.write("NaN NaN NaN NaN NaN NaN ")
fForces2.write("\n")
for n in range(0, numAtoms):
    fForces2.write("NaN NaN NaN NaN NaN NaN ")
fForces2.write("\n")
for n in range(0, numAtoms):
    fForces2.write("NaN NaN NaN NaN NaN NaN ")
fForces2.close()

fForces3 = file('./pTemp/forces3.dat', 'w')
fForces3.write("NaN NaN NaN\n")
fForces3.write("NaN NaN NaN\n")
fForces3.write("NaN NaN NaN\n")
fForces3.close()