function pvox_init(handles)
%
%PVOX_INIT 
%
%       Initialize all the mode specific data structures, and the toolbar.
%       Also set up the GUI of pvox, and delete temporary files.
%
%

% Clear pTemp folder
if strncmp(computer,'PCWIN',5)
    [s,w] = dos('mkdir pTemp');
    [s,w] = dos('del /Q pTemp\atom.out');
    [s,w] = dos('del /Q pTemp\eigenvalues.dat');
    [s,w] = dos('del /Q pTemp\fname.dat');
    [s,w] = dos('del /Q pTemp\forces.dat');
    [s,w] = dos('del /Q pTemp\forces2.dat');
    [s,w] = dos('del /Q pTemp\forces3.dat');
    [s,w] = dos('del /Q pTemp\main.dat');
    [s,w] = dos('del /Q pTemp\misc.dat');
else
    [s,w] = unix('mkdir pTemp');
    [s,w] = unix('rm -f pTemp/atom.dat');
    [s,w] = unix('rm -f pTemp/eigenvalues.dat');
    [s,w] = unix('rm -f pTemp/fname.dat');
    [s,w] = unix('rm -f pTemp/forces.dat');
    [s,w] = unix('rm -f pTemp/forces2.dat');
    [s,w] = unix('rm -f pTemp/forces3.dat');
    [s,w] = unix('rm -f pTemp/main.dat');
    [s,w] = unix('rm -f pTemp/misc.dat');
end

%
%set up toolbar
%

global Ptoolbar Phandles;

Phandles=handles;

if isfield(Ptoolbar,'tools') && ishandle(Ptoolbar.tools)
    %pvox was called another time
    return;
end

Ptoolbar.tools = uitoolbar;
Ptoolbar.open = uipushtool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/open.bmp'),'ClickedCallback','open_file','TooltipString','open');
Ptoolbar.print = uipushtool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/print.bmp'),'ClickedCallback','click_print','TooltipString','print');
Ptoolbar.capture = uipushtool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/capture.bmp'),'ClickedCallback','click_capture','TooltipString','capture figure');

Ptoolbar.zoomin = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/zoomin.bmp'),'ClickedCallback','click_zoomin','Separator','on','TooltipString','zoom in');
Ptoolbar.reset = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/reset.bmp'),'ClickedCallback','click_reset','TooltipString','reset zoom');
%Ptoolbar.zoomout = Ptoolbar.reset;
Ptoolbar.rotate = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/rotate.bmp'),'ClickedCallback','click_rotate','TooltipString','rotate');

Ptoolbar.colorbar= uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/colorbar.bmp'),'Separator','on','TooltipString','colorbar','ClickedCallback','update_state');

Ptoolbar.AtomView = uipushtool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/atomview.bmp'),'Separator','on','ClickedCallback','ParsecAtomView','TooltipString','open atom viewer');
Ptoolbar.IterationView = uipushtool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/iterview.bmp'),'ClickedCallback','ParsecIterationView','TooltipString','open iteration viewer');

Ptoolbar.M1d = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/1d.bmp'),'Separator','on','ClickedCallback','modeswitch_M1d','TooltipString','1d view');
Ptoolbar.M2d = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/2d.bmp'),'ClickedCallback','modeswitch_M2d','TooltipString','2d view');
Ptoolbar.M3d = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/3d.bmp'),'ClickedCallback','modeswitch_M3d','TooltipString','3d view');
Ptoolbar.Mdos = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/dos.bmp'),'ClickedCallback','modeswitch_Mdos','TooltipString','density of states');
Ptoolbar.Mslice = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/slice.bmp'),'ClickedCallback','modeswitch_Mslice','TooltipString','slice view');

Ptoolbar.wfn = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/wfn.bmp'),'Separator','on','ClickedCallback','graphswitch_wfn','TooltipString','individual wavefunctions');
Ptoolbar.pot = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/pot.bmp'),'ClickedCallback','graphswitch_pot','TooltipString','potential');
Ptoolbar.rho = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/rho.bmp'),'ClickedCallback','graphswitch_rho','TooltipString','overall charge density');

Ptoolbar.atoms = uitoggletool(Ptoolbar.tools,'CData',imread('./pTools/pGUI/Toolbar/atom.bmp'),'Separator','on','ClickedCallback','click_atom','TooltipString','view atoms');

% UIWAIT makes pvox wait for user response (see UIRESUME)
% uiwait(handles.figure1);

%
%SET UP GLOBAL DATA
%

%general GUI data, PguiData
global PguiData;

% Turn on compatability mode for MATLAB versions below 7
cur_version = str2num(version('-release'));
if (cur_version < 14)
    PguiData.compatability = true;
else
    PguiData.compatability = false;
end

PguiData.mode = 'carl';
PguiData.graph = 'bill';
PguiData.open_dataset = 0;
PguiData.rotate=0;
PguiData.zoom=0;
PguiData.atoms=0;
PguiData.colormap = 'default';
PguiData.colormap_invert = 0;
PguiData.gridlines = 1;
PguiData.contour_levels = [0.95 0.75 0.25];
PguiData.az = 135;
PguiData.el = 35;
PguiData.draw_mode = 1;
PguiData.wfn_universal = 0;
PguiData.workingDir = ' ';

wDir = dir('workingDir.txt');
if( (strcmp(wDir.name,'workingDir.txt')) || (strcmp(wDir.name,[cd '/workingDir.txt'])) )
    file = fopen('workingDir.txt','r');
    wDir = fgetl(file);
    fclose(file);
    if(wDir ~= -1)
        PguiData.workingDir = wDir;
    end
else
    PguiData.workingDir = [cd '/'];
end

%viewer data
global pvoxView
pvoxView.closed     =0;
pvoxView.atom       =0;
pvoxView.iter       =0;
pvoxView.about      =0;
pvoxView.pref       =0;
pvoxView.recent     =0;
pvoxView.open       =0;

%1d MODE
global pvoxM1d;
pvoxM1d.level       =1;
pvoxM1d.point_1     =[0 0 0];
pvoxM1d.point_2     =[1 0 0];
pvoxM1d.atom_1      =1;
pvoxM1d.atom_2      =2;
pvoxM1d.atomview    =1;
pvoxM1d.wfn_max     =0;
pvoxM1d.pot_max     =0;
pvoxM1d.pot_min     =0;
pvoxM1d.rho_max     =0;
pvoxM1d.init        =0;
pvoxM1d.wfn_max     =1;
pvoxM1d.pot_max     =1;
pvoxM1d.pot_min     =0;
pvoxM1d.rho_max     =1;
pvoxM1d.scale       =[0 1 0 1 0 1];

pvoxM1d.slider_level    =handles.slider_v;
pvoxM1d.edit_level      =handles.edit_top;
pvoxM1d.pulldown_1      =handles.pulldown_left;
pvoxM1d.edit_1          =handles.edit_left;
pvoxM1d.pulldown_2      =handles.pulldown_right;
pvoxM1d.edit_2          =handles.edit_right;
pvoxM1d.toggle_atoms    =handles.togglebutton_top;
pvoxM1d.toggle_plot     =handles.togglebutton_middle;
pvoxM1d.axes            =handles.axes1;

%2d MODE
global pvoxM2d;

pvoxM2d.z           =1;
pvoxM2d.level       =1;
pvoxM2d.top_down    =1;
pvoxM2d.top_down_old = 1;
pvoxM2d.init        =0;
pvoxM2d.wfn_scale   =[0 1 0 1 0 1];
pvoxM2d.pot_scale   =[0 1 0 1 0 1];
pvoxM2d.rho_scale   =[0 1 0 1 0 1];

pvoxM2d.slider_level    =handles.slider_h_top;
pvoxM2d.slider_z        =handles.slider_v;
pvoxM2d.edit_energy     =handles.edit_left;
pvoxM2d.edit_level      =handles.edit_right;
pvoxM2d.edit_z          =handles.edit_top;
pvoxM2d.toggle_top_down =handles.togglebutton_top;
pvoxM2d.toggle_surface  =handles.togglebutton_middle;
pvoxM2d.axes            =handles.axes1;

%3d MODE
global pvoxM3d;
pvoxM3d.level       =1;
pvoxM3d.color       =0;
pvoxM3d.num_slices  =1;
pvoxM3d.init        =0;
pvoxM3d.wfn_scale   =[0 1 0 1 0 1];
pvoxM3d.pot_scale   =[0 1 0 1 0 1];
pvoxM3d.rho_scale   =[0 1 0 1 0 1];

pvoxM3d.slider_level    =handles.slider_h_top;
pvoxM3d.edit_energy     =handles.edit_left;
pvoxM3d.edit_level      =handles.edit_right;
pvoxM3d.edit_num_slices =handles.edit_top;
pvoxM3d.toggle_contour  =handles.togglebutton_top;
pvoxM3d.toggle_color    =handles.togglebutton_middle;
pvoxM3d.axes            =handles.axes1;

%dos MODE
global pvoxMdos;
pvoxMdos.width      =0.01;
pvoxMdos.iteration  =1;
pvoxMdos.occupied   =0;
pvoxMdos.cumulative =1;
pvoxMdos.init       =0;

pvoxMdos.slider_iter        =handles.slider_h_top;
pvoxMdos.edit_width         =handles.edit_left;
pvoxMdos.edit_iter          =handles.edit_right;
pvoxMdos.toggle_cumulative  =handles.togglebutton_top;
pvoxMdos.toggle_occupied    =handles.togglebutton_middle;
pvoxMdos.axes               =handles.axes1;

%slice MODE
global pvoxMslice;
pvoxMslice.level    =1;
pvoxMslice.x        =1;
pvoxMslice.y        =1;
pvoxMslice.z        =1;
pvoxMslice.init     =0;
pvoxMslice.wfn_scale   =[0 1 0 1 0 1];
pvoxMslice.pot_scale   =[0 1 0 1 0 1];
pvoxMslice.rho_scale   =[0 1 0 1 0 1];

pvoxMslice.slider_x         =handles.slider_h_top;
pvoxMslice.slider_y         =handles.slider_h_middle;
pvoxMslice.slider_z         =handles.slider_h_bottom;
pvoxMslice.slider_level     =handles.slider_v;
pvoxMslice.edit_level       =handles.edit_top;
pvoxMslice.title_energy     =handles.togglebutton_top;
pvoxMslice.toggle_energy    =handles.togglebutton_middle;
pvoxMslice.axes             =handles.axes1;

%
%set things to invisible
%

set(handles.slider_h_top,'Visible','off');
set(handles.slider_h_middle,'Visible','off');
set(handles.slider_h_bottom,'Visible','off');
set(handles.text_h_top,'Visible','off');
set(handles.text_h_middle,'Visible','off');
set(handles.text_h_bottom,'Visible','off');

set(handles.text_left,'Visible','off');
set(handles.edit_left,'Visible','off');
set(handles.text_right,'Visible','off');
set(handles.edit_right,'Visible','off');

set(handles.togglebutton_top,'Visible','off');
set(handles.togglebutton_middle,'Visible','off');
set(handles.togglebutton_bottom,'Visible','off');

set(handles.slider_v,'Visible','off');
set(handles.text_top,'Visible','off');
set(handles.edit_top,'Visible','off');

set(handles.menu_pot,'Enable','off');
set(handles.menu_rho,'Enable','off');
set(handles.menu_wfn,'Enable','off');
set(handles.menu_atoms,'Enable','off');

set(handles.menu_print,'Enable','off');
set(handles.menu_capture,'Enable','off');
set(handles.menu_preferences,'Enable','off');

set(handles.menu_1d,'Enable','off');
set(handles.menu_2d,'Enable','off');
set(handles.menu_3d,'Enable','off');
set(handles.menu_dos,'Enable','off');
set(handles.menu_slice,'Enable','off');

set(handles.pulldown_left,'Visible','off');
set(handles.pulldown_right,'Visible','off');

set(Ptoolbar.M1d,'Enable','off');
set(Ptoolbar.M2d,'Enable','off');
set(Ptoolbar.M3d,'Enable','off');
set(Ptoolbar.Mdos,'Enable','off');
set(Ptoolbar.Mslice,'Enable','off');

set(Ptoolbar.pot,'Enable','off');
set(Ptoolbar.rho,'Enable','off');
set(Ptoolbar.wfn,'Enable','off');
set(Ptoolbar.atoms,'Enable','off');
set(Ptoolbar.print,'Enable','off');
set(Ptoolbar.capture,'Enable','off');

set(Ptoolbar.AtomView,'Enable','off');
set(Ptoolbar.IterationView,'Enable','off');

set(Ptoolbar.zoomin,'Enable','off');
set(Ptoolbar.reset,'Enable','off');
set(Ptoolbar.rotate,'Enable','off');
set(Ptoolbar.colorbar,'Enable','off');

% Remove Colorbar for matlab versions older that 7
%if (PguiData.compatability)
%    set(Ptoolbar.colorbar,'Visible','off');
%end


set(handles.axes1,'Visible','off');
